Adjust clang format to the new versions, revert broken macro layout (#714)
This commit is contained in:
committed by
GitHub
parent
ed877433f3
commit
2ff2316227
@@ -28,9 +28,9 @@ THE SOFTWARE.
|
||||
* @ingroup TextureTest
|
||||
*/
|
||||
|
||||
template <bool normalizedCoords>
|
||||
__global__ void tex1DKernel(float* outputData, hipTextureObject_t textureObject, int width,
|
||||
float offsetX) {
|
||||
template <bool normalizedCoords> __global__ void tex1DKernel(float* outputData,
|
||||
hipTextureObject_t textureObject,
|
||||
int width, float offsetX) {
|
||||
#if !__HIP_NO_IMAGE_SUPPORT
|
||||
int x = blockIdx.x * blockDim.x + threadIdx.x;
|
||||
outputData[x] =
|
||||
|
||||
Reference in New Issue
Block a user